@@ -104,6 +104,28 @@ class LineGroup(object):
         except Exception as e:
             raise e
 
+    def sendSticker(self,
+                    stickerId = "1",
+                    stickerPackageId = "1",
+                    stickerVersion = "100",
+                    stickerText="[null]"):
+        try:
+            message = CurveThrift.Message(to=self.id, text="")
+            message.contentType = CurveThrift.ContentType.STICKER
+
+            message.contentMetadata = {
+                'STKID': stickerId,
+                'STKPKGID': stickerPackageId,
+                'STKVER': stickerVersion,
+                'STKTXT': stickerText,
+            }
+
+            self._client._sendMessage(message)
+
+            return True
+        except Exception as e:
+            raise e
+
     def getRecentMessages(self, count=1):
         """Get recent messages"""
         try:
@@ -148,6 +170,28 @@ class LineContact(object):
             messages = self._client._getRecentMessages(self.messageBox.id, count)
             return messages
 
+    def sendSticker(self,
+                    stickerId = "1",
+                    stickerPackageId = "1",
+                    stickerVersion = "100",
+                    stickerText="[null]"):
+        try:
+            message = CurveThrift.Message(to=self.id, text="")
+            message.contentType = CurveThrift.ContentType.STICKER
+
+            message.contentMetadata = {
+                'STKID': stickerId,
+                'STKPKGID': stickerPackageId,
+                'STKVER': stickerVersion,
+                'STKTXT': stickerText,
+            }
+
+            self._client._sendMessage(message)
+
+            return True
+        except Exception as e:
+            raise e
+
     def sendImage(self, path):
         try:
             img = open(path, 'r')
@@ -193,27 +237,6 @@ class LineContact(object):
         except Exception as e:
             raise e
 
-    def sendSticker(self, url):
-        try:
-            response = requests.get(url, stream=True)
-
-            message = CurveThrift.Message(to=self.id, text=None)
-            message.contentType = CurveThrift.ContentType.IMAGE
-            message.contentPreview = response.raw.read()
-            #message.contentPreview = url.encode('utf-8')
-
-            message.contentMetadata = {
-                'PREVIEW_URL': url,
-                'DOWNLOAD_URL': url,
-                'PUBLIC': "True",
-            }
-
-            self._client._sendMessage(message, seq=1)
-
-            return True
-        except Exception as e:
-            raise e
-
     def sendMessage(self, text):
         try:
             message = CurveThrift.Message(to=self.id, text=text)
